@@ -33,8 +33,8 @@ ac_get_custom_deal_fields <- function() {
                  add_headers("Api-Token" = Sys.getenv('ACTIVECAMPAGN_API_TOKEN')))
     },
     until = ~ status_code(.) == 200,
-    interval  = getOption('ractivecampaig.max_tries'),
-    max_tries = getOption('ractivecampaig.interval')
+    interval  = getOption('ractivecampaig.interval'),
+    max_tries = getOption('ractivecampaig.max_tries')
     )
 
     data <- content(ans)
@@ -44,7 +44,7 @@ ac_get_custom_deal_fields <- function() {
     }
 
     out_data <- tibble(data = data$dealCustomFieldMeta) %>%
-                unnest_wider(data)
+                unnest_wider(data, transform = list(fieldDefault = function(x) paste(x, sep = ', ')))
 
     is_first_iteration <- FALSE
     offset <- offset + limit
