@@ -19,6 +19,10 @@ ac_get_custom_deal_fields_values <- function(
 
   ac_check_auth()
 
+  if ( length(deal_id) > 0 ) {
+    deal_id <- paste0(deal_id, collapse = ',')
+  }
+
   # vars
   is_first_iteration <- TRUE
   limit  <- 100
@@ -29,11 +33,18 @@ ac_get_custom_deal_fields_values <- function(
   while ( (is.na(total) | offset <= total) | is_first_iteration  ) {
 
     # send request
-    ans <- GET(str_glue("{Sys.getenv('ACTIVECAMPAGN_API_URL')}/api/3/dealCustomFieldData"),
-               query = list(limit  = limit,
-                            offset = offset,
-                            "filters[dealId]" = deal_id),
-               add_headers("Api-Token" = Sys.getenv('ACTIVECAMPAGN_API_TOKEN')))
+    retry(
+      {
+      ans <- GET(str_glue("{Sys.getenv('ACTIVECAMPAGN_API_URL')}/api/3/dealCustomFieldData"),
+                 query = list(limit  = limit,
+                              offset = offset,
+                              "filters[dealId]" = deal_id),
+                 add_headers("Api-Token" = Sys.getenv('ACTIVECAMPAGN_API_TOKEN')))
+      },
+      until = ~ status_code(.) == 200,
+      interval  = getOption('ractivecampaig.interval'),
+      max_tries = getOption('ractivecampaig.max_tries')
+    )
 
     data <- content(ans)
 
@@ -42,7 +53,7 @@ ac_get_custom_deal_fields_values <- function(
     }
 
     out_data <- tibble(data = data$dealCustomFieldData) %>%
-                unnest_wider(data)
+                unnest_wider(data, transform = list(fieldValue = function(x) paste(x, collapse = ', ')))
 
     is_first_iteration <- FALSE
     offset <- offset + limit
