@@ -57,6 +57,17 @@ ac_get_deals <- function(
   score              = NULL
 ) {
 
+  # cli options
+  oldpar <- options(
+    'cli.progress_show_after',
+    'cli.progress_clear',
+    'cli.spinner'
+  )
+
+  on.exit(options(oldpar))
+
+  ac_progress_bar_set()
+
   ac_check_auth()
 
   # vars
@@ -66,6 +77,9 @@ ac_get_deals <- function(
   total  <- NA
   res    <- list()
 
+  # pb
+  cli_progress_bar("Loading deals")
+
   while ( (is.na(total) | offset <= total) | is_first_iteration  ) {
 
     # send request
@@ -97,8 +111,8 @@ ac_get_deals <- function(
                  add_headers("Api-Token" = Sys.getenv('ACTIVECAMPAGN_API_TOKEN')))
       },
       until = ~ status_code(.) == 200,
-      interval  = getOption('ractivecampaig.max_tries'),
-      max_tries = getOption('ractivecampaig.interval')
+      interval  = getOption('ractivecampaig.interval'),
+      max_tries = getOption('ractivecampaig.max_tries')
     )
 
     data <- content(ans)
@@ -116,9 +130,14 @@ ac_get_deals <- function(
     res <- append(res, list(out_data))
 
     Sys.sleep(0.25)
+    # pb
+    cli_progress_update()
 
   }
 
+  # pb
+  cli_progress_update(force = TRUE)
+
   res <- bind_rows(res) %>%
          mutate(value = as.numeric(value) / 100)
 
